@@ -17,6 +17,7 @@ class DegreeSPINE(EnsmallenEmbedder):
         maximum_depth: Optional[int] = None,
         path: Optional[str] = None,
         verbose: bool = False,
+        ring_bell: bool = False,
         enable_cache: bool = False
     ):
         """Create new Degree-based SPINE method.
@@ -34,6 +35,8 @@ class DegreeSPINE(EnsmallenEmbedder):
             This parameter is necessary to embed very large graphs.
         verbose: bool = False
             Whether to show loading bars.
+        ring_bell: bool = False,
+            Whether to play a sound when embedding completes.
         enable_cache: bool = False
             Whether to enable the cache, that is to
             store the computed embedding.
@@ -51,6 +54,7 @@ class DegreeSPINE(EnsmallenEmbedder):
 
         super().__init__(
             embedding_size=embedding_size,
+            ring_bell=ring_bell,
             enable_cache=enable_cache
         )
 
