@@ -15,6 +15,7 @@ class GLEEEnsmallen(EnsmallenEmbedder):
     def __init__(
         self,
         embedding_size: int = 100,
+        ring_bell: bool = False,
         enable_cache: bool = False
     ):
         """Create new GLEE method.
@@ -23,12 +24,15 @@ class GLEEEnsmallen(EnsmallenEmbedder):
         --------------------------
         embedding_size: int = 100
             Dimension of the embedding.
+        ring_bell: bool = False,
+            Whether to play a sound when embedding completes.
         enable_cache: bool = False
             Whether to enable the cache, that is to
             store the computed embedding.
         """
         super().__init__(
             embedding_size=embedding_size,
+            ring_bell=ring_bell,
             enable_cache=enable_cache,
         )
 
