@@ -21,6 +21,7 @@ class TransEEnsmallen(SiameseEnsmallen):
         dtype: str = "f32",
         random_state: int = 42,
         verbose: bool = False,
+        ring_bell: bool = False,
         enable_cache: bool = False
     ):
         """Create new TransE method.
@@ -54,6 +55,8 @@ class TransEEnsmallen(SiameseEnsmallen):
             Random state to reproduce the embeddings.
         verbose: bool = False
             Whether to show loading bars.
+        ring_bell: bool = False,
+            Whether to play a sound when embedding completes.
         enable_cache: bool = False
             Whether to enable the cache, that is to
             store the computed embedding.
@@ -69,6 +72,7 @@ class TransEEnsmallen(SiameseEnsmallen):
             dtype=dtype,
             random_state=random_state,
             verbose=verbose,
+            ring_bell=ring_bell,
             enable_cache=enable_cache,
         )
 
