@@ -20,6 +20,7 @@ class UnstructuredEnsmallen(SiameseEnsmallen):
         dtype: str = "f32",
         random_state: int = 42,
         verbose: bool = False,
+        ring_bell: bool = False,
         enable_cache: bool = False
     ):
         """Create new abstract Node2Vec method.
@@ -49,6 +50,8 @@ class UnstructuredEnsmallen(SiameseEnsmallen):
             Random state to reproduce the embeddings.
         verbose: bool = False
             Whether to show loading bars.
+        ring_bell: bool = False,
+            Whether to play a sound when embedding completes.
         enable_cache: bool = False
             Whether to enable the cache, that is to
             store the computed embedding.
@@ -63,6 +66,7 @@ class UnstructuredEnsmallen(SiameseEnsmallen):
             dtype=dtype,
             random_state=random_state,
             verbose=verbose,
+            ring_bell=ring_bell,
             enable_cache=enable_cache,
         )
 
