@@ -20,6 +20,7 @@ class BoxEPyKEEN(EntityRelationEmbeddingModelPyKEEN):
                              ] = "Stochastic Local Closed World Assumption",
         verbose: bool = False,
         random_state: int = 42,
+        ring_bell: bool = False,
         enable_cache: bool = False
     ):
         """Create new PyKEEN BoxE model.
@@ -59,6 +60,8 @@ class BoxEPyKEEN(EntityRelationEmbeddingModelPyKEEN):
             Whether to show loading bars.
         random_state: int = 42
             Random seed to use while training the model
+        ring_bell: bool = False,
+            Whether to play a sound when embedding completes.
         enable_cache: bool = False
             Whether to enable the cache, that is to
             store the computed embedding.
@@ -73,6 +76,7 @@ class BoxEPyKEEN(EntityRelationEmbeddingModelPyKEEN):
             training_loop=training_loop,
             verbose=verbose,
             random_state=random_state,
+            ring_bell=ring_bell,
             enable_cache=enable_cache
         )
 
