@@ -27,6 +27,7 @@ class ConvEPyKEEN(EntityRelationEmbeddingModelPyKEEN):
                              ] = "Stochastic Local Closed World Assumption",
         verbose: bool = False,
         random_state: int = 42,
+        ring_bell: bool = False,
         enable_cache: bool = False
     ):
         """Create new PyKEEN ConvE model.
@@ -81,6 +82,8 @@ class ConvEPyKEEN(EntityRelationEmbeddingModelPyKEEN):
             Whether to show loading bars.
         random_state: int = 42
             Random seed to use while training the model
+        ring_bell: bool = False,
+            Whether to play a sound when embedding completes.
         enable_cache: bool = False
             Whether to enable the cache, that is to
             store the computed embedding.
@@ -102,6 +105,7 @@ class ConvEPyKEEN(EntityRelationEmbeddingModelPyKEEN):
             training_loop=training_loop,
             verbose=verbose,
             random_state=random_state,
+            ring_bell=ring_bell,
             enable_cache=enable_cache
         )
 
