@@ -34,6 +34,7 @@ class Siamese(TensorFlowEmbedder):
         use_mirrored_strategy: bool = False,
         optimizer: str = "nadam",
         verbose: bool = False,
+        ring_bell: bool = False,
         enable_cache: bool = False,
         random_state: int = 42
     ):
@@ -72,6 +73,8 @@ class Siamese(TensorFlowEmbedder):
             The optimizer to be used during the training of the model.
         verbose: bool = False
             Whether to show loading bars.
+        ring_bell: bool = False,
+            Whether to play a sound when embedding completes.
         enable_cache: bool = False
             Whether to enable the cache, that is to
             store the computed embedding.
@@ -92,6 +95,7 @@ class Siamese(TensorFlowEmbedder):
             verbose=verbose,
             use_mirrored_strategy=use_mirrored_strategy,
             enable_cache=enable_cache,
+            ring_bell=ring_bell,
             random_state=random_state
         )
 
