@@ -16,6 +16,7 @@ class AbstractEmbeddingModel(AbstractModel):
         self,
         embedding_size: int,
         enable_cache: bool = False,
+        ring_bell: bool = False,
         random_state: Optional[int] = None
     ):
         """Create new embedding model.
@@ -27,6 +28,8 @@ class AbstractEmbeddingModel(AbstractModel):
         enable_cache: bool = False
             Whether to enable the cache, that is to
             store the computed embedding.
+        ring_bell: bool = False
+            Whether to play a sound when embedding completes.
         random_state: Optional[int] = None
             The random state to use if the model is stocastic.
         """
@@ -39,6 +42,15 @@ class AbstractEmbeddingModel(AbstractModel):
         self._embedding_size = embedding_size
         self._enable_cache = enable_cache
 
+        try:
+            from ringbell import RingBell
+            self._ring_bell = RingBell(
+                verbose=ring_bell,
+                sample="positive_notification"
+            )
+        except ModuleNotFoundError:
+            self._ring_bell = None
+
     def parameters(self) -> Dict[str, Any]:
         """Returns parameters of the embedding model."""
         return dict(
@@ -189,6 +201,9 @@ class AbstractEmbeddingModel(AbstractModel):
                 f"but returns an object of type {type(result)}."
             )
 
+        if self._ring_bell is not None:
+            self._ring_bell.play()
+
         return result
 
     def fit_transform(
